#
# spec file for package vpp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _vpp_build_dir       %{buildroot}/../../BUILD/vpp-v%{version}/build
%define _vpp_install_dir     %{_vpp_build_dir}/
%define _vpp_plugins_lib_dir %{_vpp_install_dir}/lib

%define lname libvpp0

Name:           vpp
Version:        19.4~rc0
Release:        lp152.2.97
Summary:        Set of libraries and drivers for fast packet processing
License:        Apache-2.0
Group:          Productivity/Networking/Routing
Url:            https://wiki.fd.io/view/VPP
Source0:        vpp-v19.4~rc0.tar.gz
Patch0:         enable-shared-dpdk.patch
Patch1:         startup-conf.patch
Patch2:         remove-git.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  ccache
BuildRequires:  check-devel
BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  distribution-release
BuildRequires:  dpdk-devel => 18.11
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
BuildRequires:  git
BuildRequires:  glibc-devel
BuildRequires:  glibc-devel-static
#BuildRequires:  java-devel >= 1.8
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libnuma-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  lsb-release
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  python-devel
BuildRequires:  python-pip
BuildRequires:  python-rpm-macros
BuildRequires:  python2-ply
BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  rdma-core-devel
BuildRequires:  shadow
Conflicts:      otherproviders(vpp-any)
Provides:       %{name}-any = %{version}
ExclusiveArch:  x86_64
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-rpm-macros
%endif

%description
The Vector Packet Processing platform is a framework that provides
switch/router functionality. It is based on Cisco's packet processing
stack that can run on commodity CPUs.
This package provides VPP executables: vpp, vpp_api_test, vpp_json_test
vpp - the vector packet engine
vpp_api_test - vector packet engine API test tool
vpp_json_test - vector packet engine JSON test tool

%package -n %{lname}
Summary:        VPP libraries
Group:          System/Libraries
Provides:       %{lname}-any = %{version}

%description -n %{lname}
This package contains the VPP shared libraries, including:
vppinfra - foundation library supporting vectors, hashes, bitmaps, pools, and string formatting.
svm - vm library
vlib - vector processing library
vlib-api - binary API library
vnet -  network stack library

%package devel
Summary:        VPP header files, static libraries
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Conflicts:      otherproviders(%{name}-any-devel)
Provides:       %{name}-any-devel = %{version}

%description devel
This package contains the header files for VPP.
Install this package if you want to write a
program for compilation and linking with vpp lib.
vlib
vlibmemory
vnet - devices, classify, dhcp, ethernet flow, gre, ip, etc.
vpp-api
vppinfra

%package plugins
Summary:        Vector Packet Processing--runtime plugins
Group:          Productivity/Networking/Routing
Conflicts:      otherproviders(%{name}-any-plugins)
Provides:       %{name}-any-plugins = %{version}

%description plugins
This package contains the VPP plugins which are loaded by VPP at startup

%package api-lua
Summary:        VPP api lua bindings
Group:          Development/Libraries/Other
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Conflicts:      otherproviders(%{name}-any-api-lua)
Provides:       %{name}-any-api-lua = %{version}

%description api-lua
This package contains the lua bindings for the vpp api

#%package api-java
#Summary:        VPP api java bindings
#Group:          Development/Libraries/Java
#Requires:       %{lname} = %{version}
#Requires:       %{name} = %{version}
#Requires:       %{name}-devel = %{version}
#Conflicts:      otherproviders(%{name}-any-api-java)
#Provides:       %{name}-any-api-java = %{version}

#%description api-java
#This package contains the java bindings for the vpp api

%package api-python
Summary:        VPP api python bindings
Group:          Development/Libraries/Python
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       python-setuptools
Conflicts:      otherproviders(%{name}-any-python-api)
Provides:       %{name}-any-python-api = %{version}

%description api-python
This package contains the python bindings for the vpp api

%prep
%setup -q -n %{name}-v%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
export VPP_BUILD_USER=suse
export VPP_BUILD_HOST=SUSE

cd build 
cmake ../src
make CC=gcc-7 CXX=g++-7 PLATFORM=vpp TAG=vpp MAKE_PARALLEL_JOBS="%{?_smp_mflags}" 

cd - 
cd ./src/vpp-api/python && %{py2_build}
cd - 

%pre
# Add the vpp group
getent group vpp >/dev/null || groupadd -r vpp
%service_add_pre vpp.service

%install
#
# binaries
#
mkdir -p -m755 %{buildroot}%{_bindir}
mkdir -p -m755 %{buildroot}%{_unitdir}
install  -m 755 %{_vpp_install_dir}/bin/* %{buildroot}%{_bindir}

# api
mkdir -p -m755 %{buildroot}%{_datadir}/vpp/api

#
# core api
#
mkdir -p -m755 %{buildroot}%{_datadir}/vpp/api
for file in $(find %{_vpp_install_dir}-type f -name '*.api.json' -print )
do
        install -p -m 755 $file %{buildroot}%{_datadir}/vpp/api
done

#
# configs
#
mkdir -p -m755 %{buildroot}%{_sysconfdir}/vpp
mkdir -p -m755 %{buildroot}%{_sysconfdir}/sysctl.d
install -p -m 644 %{_vpp_build_dir}/../extras/rpm/vpp.service %{buildroot}%{_unitdir}
install -p -m 644 %{_vpp_build_dir}/../src/vpp/conf/startup.conf %{buildroot}%{_sysconfdir}/vpp/startup.conf
#
# libraries
#
mkdir -p -m755 %{buildroot}%{_libdir}
mkdir -p -m755 %{buildroot}%{_sysconfdir}/bash_completion.d
mkdir -p -m755 %{buildroot}%{_datadir}/vpp
for file in $(find %{_vpp_install_dir}/lib* -type f -name '*.so.*.*' -print )
do
	install -p -m 755 $file %{buildroot}%{_libdir}
done
for file in $(cd %{buildroot}%{_libdir} && find . -type f -print | sed -e 's/^\.\///')
do
	# make lib symlinks
	( cd %{buildroot}%{_libdir} &&
          ln -fs $file $(echo $file | sed -e 's/\(\.so\)\.[0-9]\+.*/\1/') )
done
for file in $(find %{_vpp_install_dir}/vpp/share/vpp/api  -type f -name '*.api.json' -print )
do
        install -p -m 644 $file %{buildroot}%{_datadir}/vpp/api
done
install -p -m 644 %{_vpp_build_dir}/../src/scripts/vppctl_completion %{buildroot}%{_sysconfdir}/bash_completion.d

# Lua bindings
mkdir -p -m755 %{buildroot}%{_datadir}/doc/vpp/examples/lua/examples/cli
mkdir -p -m755 %{buildroot}%{_datadir}/doc/vpp/examples/lua/examples/lute
for file in $(cd %{_vpp_install_dir}/../../src/vpp-api/lua && git ls-files .)
do
        install -p -m 644 %{_vpp_install_dir}/../../src/vpp-api/lua/$file \
           %{buildroot}%{_datadir}/doc/vpp/examples/lua/$file
done

# Java bindings
#mkdir -p -m755 %{buildroot}%{_datadir}/java
#for file in $(find %{_vpp_install_dir}/vpp/share/java -type f -name '*.jar' -print )
#do
#        install -p -m 644 $file %{buildroot}%{_datadir}/java
#done

# Python bindings
cd %{_vpp_build_dir}/../src/vpp-api/python && %{py2_install}

#
# devel
#
for dir in $(find %{_vpp_install_dir}/../src -maxdepth 0 -type d -print | grep -v dpdk)
do
	for subdir in $(cd ${dir} && find . -type d -print)
	do
		mkdir -p -m755 %{buildroot}%{_includedir}/${subdir}
	done
	for file in $(cd ${dir} && find . -type f -print)
	do
		install -p -m 644 $dir/$file %{buildroot}%{_includedir}/$file
	done
done

mkdir -p -m755 %{buildroot}%{python_sitelib}/jvppgen
install -p -m755 %{_vpp_build_dir}/../extras/japi/java/jvpp/gen/jvpp_gen.py %{buildroot}%{_prefix}/bin
for i in $(ls %{_vpp_build_dir}/../extras/japi/java/jvpp/gen/jvppgen/*.py); do
   install -p -m755 ${i} %{buildroot}%{python_sitelib}/jvppgen
done;

# sample plugin
mkdir -p -m755 %{buildroot}%{_datadir}/doc/vpp/examples/sample-plugin/sample
for file in $(cd %{_vpp_install_dir}/../../sample-plugin && find -type f -print)
do
	install -p -m 644 %{_vpp_install_dir}/../../sample-plugin/$file \
	   %{buildroot}%{_datadir}/doc/vpp/examples/sample-plugin/$file
done

#
# vpp-plugins
#
mkdir -p -m755 %{buildroot}%{_libdir}/vpp_plugins
mkdir -p -m755 %{buildroot}%{_libdir}/vpp_api_test_plugins
for file in $(cd %{_vpp_plugins_lib_dir}/vpp_plugins && find -type f -print)
do
        install -p -m 644 %{_vpp_plugins_lib_dir}/vpp_plugins/$file \
           %{buildroot}/%{_libdir}/vpp_plugins/$file
done

for file in $(cd %{_vpp_plugins_lib_dir}/vpp_api_test_plugins && find -type f -print)
do
        install -p -m 644 %{_vpp_plugins_lib_dir}/vpp_api_test_plugins/$file \
           %{buildroot}/%{_libdir}/vpp_api_test_plugins/$file
done

for file in $(find %{_vpp_install_dir}/plugins -type f -name '*.api.json' -print )
do
        install -p -m 644 $file %{buildroot}%{_datadir}/vpp/api
done

#
# remove RPATH from ELF binaries
#
%{_vpp_build_dir}/../build-root/scripts/remove-rpath %{buildroot}

export NO_BRP_CHECK_RPATH=true

%post
%service_add_post vpp.service

%post -n %{lname} -p /sbin/ldconfig

%preun
%service_del_preun vpp.service

%postun
%service_del_postun vpp.service

%postun -n %{lname} -p /sbin/ldconfig

%files
%{_unitdir}/vpp.service
%{_bindir}/vpp*
%{_bindir}/svm*
%{_bindir}/elftool
%{_bindir}/sock_test_client
%{_bindir}/sock_test_server
%{_bindir}/tcp_echo
%{_bindir}/udp_echo
%{_bindir}/vcl_test_client
%{_bindir}/vcl_test_server

%dir %{_sysconfdir}/vpp
%config %{_sysconfdir}/vpp/startup.conf
%{_sysconfdir}/bash_completion.d/vppctl_completion
%license LICENSE

%files -n %{lname}
%exclude %{_libdir}/vpp_plugins
%exclude %{_libdir}/vpp_api_test_plugins
%{_libdir}/*.so.*

%files api-lua
%{_datadir}/doc/vpp/examples/lua

#%files api-java
#%{_datadir}/java/*

%files api-python
%dir %{python_sitelib}/vpp_papi*
%{python_sitelib}/vpp_papi*

%files devel
%dir %{python_sitelib}/jvppgen
%{python_sitelib}/jvppgen/*
%dir %{_datadir}/doc/vpp
%dir %{_datadir}/doc/vpp/examples
%{_libdir}/*.so
%{_bindir}/jvpp_gen.py
%{_includedir}/*
%{_datadir}/doc/vpp/examples/sample-plugin
%dir %{_datadir}/vpp
%dir %{_datadir}/vpp/api
%{_datadir}/vpp/api/*

%files plugins
%dir %{_libdir}/vpp_plugins
%dir %{_libdir}/vpp_api_test_plugins
%{_libdir}/vpp_plugins/*.so*
%{_libdir}/vpp_api_test_plugins/*.so*

%changelog
* Tue Jan 29 2019 ndas@suse.de
- Update to v19.4-rc0((fate#325916, fate#325951 fate#326025, fate#326992):)
  * Infrastructure
    DPDK 18.11 integration
    New Stats infrastructure (interface, error, node performance counters)
    Add configurable "Doug Lea malloc" support
  * VNET & Plugins
    Load balancing: support per-port VIP and all-port VIP
    Port NSH plugin to VPP
    NAT
    Configurable port range
    Virtual Fragmentation Reassembly for endpoint-dependent mode
    Client-IP based session affinity for load-balancing
    TCP MSS clamping
    Session timeout
    Bug-fixing and performance optimizations
  * Host stack
    Support for applications with multiple workers
    Support for binds from multiple app workers to same ip:port
    Switched to a message queue for io and control event notifications
    Support for eventfd based notifications as alternative to mutext-condvar pair
    VCL refactor to support async event notifications and multiple workers
    TLS async support in client for HW accleration
    Performance optimizations and bug-fixing
  [- deps.patch,
  - fix-nojavah.patch,
    + remove-git.patch,
  * enable-shared-dpdk.patch,
  * startup-conf.patch ]
- removed api-java package till we find a fix
* Mon Oct 22 2018 Marco Varlese <marco.varlese@suse.com>
- Do not install 80-vpp.conf; it modifies system-wide settings and
  it is not needed since VPP 17.08 (boo#1112540)
* Tue Oct  2 2018 Jan Engelhardt <jengelh@inai.de>
- Really fix boo#1110294 by correcting broken build
  descriptions with regard to library dependencies.
  Adds deps.patch. Removes reproducible_build.patch.
- Parallelize build according to rpmbuild flags.
* Mon Oct  1 2018 Marco Varlese <marco.varlese@suse.com>
- Added reproducible_build.patch to fix boo#1110294:
  Wrong dependencies caused build to fail with 'make' option '-j1'
* Fri Sep 21 2018 Marco Varlese <marco.varlese@suse.com>
- Upgrade to v18.07.1; some of the new features include:
  * IGMP improvements
  - Enable/Disable an interface for IGMP
  - improve logging
  - refactor common code
  - no orphaned timers
  - IGMP state changes in main thread only
  - Large groups split over multiple state-change reports
  - SSM range configuration API.
  - more tests
  * IP: vectorized IP checksum
  - VXLAN : HW offload RX flow
  - Rework kube-proxy into LB plugin and add NATA66
  * ACL:
  - Tuple Merge algorithm cleanup and integration
  - Processing pipeline optimizations
  - Refactoring
  * Experimental AVF driver
  * Session: performance improvements, add support for connectionless
  transports, datagram reception and transmission
  * TCP: congestion control improvements and overall fixes
  * UDP: datagram mode
  * TLS async support
- Removed fix-nojavah.patch since merged upstream
* Thu Aug 30 2018 marco.varlese@suse.com
- Using "install-packages" to build VPP: this is inline with upstream
  recommendation
* Tue Jun 26 2018 marco.varlese@suse.com
- Removed "make bootstrap" since no longer required with latest
  release
* Thu Jun 21 2018 marco.varlese@suse.com
- Using gcc7 compiler
* Thu Apr 26 2018 marco.varlese@suse.com
- Update to v18.04-release. Some of the enhancements are:
  * Infrastructure
  - DPDK 18.02.1
  - ARM aarch64 integrated into CI
  - ERSPAN
  - L3DSR load balancing support
  - VPC bonding / LACP
  - IPv4/IPv6 packet reassembly
  - IPv6 link-local support
  - Asymmetrical static NAT
  - 464XLAT for NAT44
  - MAP-T CE support
  - Intel Adaptive Virtual Function native device driver plugin
  - Marvell device plugin
  - SRv6 static, dynamic and masquerading proxy plugins
  - MPLS Uniform mode
  - IGMP plugin
  - IPIP tunnel support (IPv4/IPv6 over IPv4/IPv6)
  - IPv6 Router Discovery mechanism
  * VLIB
  - ARM-optimized library variations for key functions
  - Better handling of physmem on non-NUMA kernels
  * Host stack
  - TLS support via OpenSSL or mbedtls software engines
  - Session layer can utilize both shm and memfd (secure) FIFO segments
  - STCP
  - VCL logging / tracing
- Added mbedtls-devel to enable TLS support
- Renamed 0001-enable-shared.patch to enable-shared-dpdk.patch
- Renamed 0003-startup-conf.patch to startup-conf.patch
- Combined vpp-17.10-java9.patch and vpp-18.01-nojavah.patch in
  fix-nojavah.patch
- Removed memfd-create.patch because merged upstream
* Wed Mar 21 2018 marco.varlese@suse.com
- Added runtime dependency on -devel package since all -api packages
  require header/json files at runtime
* Mon Mar  5 2018 marco.varlese@suse.de
- Added memfd-create.patch to fix the memfd_create issue caused by the upgrade to glibc 2.27
* Wed Jan 24 2018 marco.varlese@suse.de
- Update to the stable version of 18.01 release. More than 560 commits since the 17.10 release:
  * Features
  - Infrastructure
  * DPDK 17.11
  * TCP Checksum Offload
  * Arm64/Arm-v8 support
  * SUSE packaging
  * bihash_vec8_8 variant
  * PCI rework to support VFIO
  * chi-squared test calculator
  - SNAT / NAT
  * One armed NAT
  * Twice NAT44
  * NAT hairpinning rework
  * NAT64 multi-thread
  * NAT64 IPFix
  * NAT64 Fragmentation
  * NAT: DS-Lite
  * Remove old SNAT API
  * ACL-based NAT
  - VNET
  * DNS name resolver
  * BIER
  * GENEVE Tunnel
  * IPSec Openssl 1.1.0 api support
  * FIB improvements
  * tap v2
  - API
  * VPP stats (Broadcast & Multicast support)
  * SR MPLS
  * VPP Object Model (VOM)
  - Host Stack
  * VPP TCP Stack scale / congestion improvements
  * Refactor UDP
  * Namespace support
  * VPP Comms Library (VCL) improvements
  - ACL
  * ACL stats
  - Plugins
  * Kube-proxy
  * L2 Emulation
  * Memif
  * Known issues
  - For the full list of issues please refer to fd.io [JIRA](https://jira.fd.io).
  * Issues fixed
  - For the full list of fixed issues please refer to: fd.io [JIRA](https://jira.fd.io)
* Mon Jan 22 2018 marco.varlese@suse.de
- Latest update to DPDK 17.11 required rdma-core-devel to enable Mellanox NIC. Being VPP dependant on DPDK, it required the same build-dependency to be added.
* Tue Jan  9 2018 marco.varlese@suse.de
- Updated to -RC1 release (v18.01-rc1); some of the fixes include:
  * NAT64: free port when dynamic BIB deleted (VPP-1107)
  * VOM: NAT updates
  * tcp: add builtin server/client transfer test
  * fib: make deag entries urpf extempt
  * VPP-1109 Fix loop for some CLI (code review)
  * L2 Emulation
  * Translate matching packets using NAT (VPP-1069)
  * Fix MPLS local-label CLI help string
  * VPP-1083 "ip punt redirect add" crashed if not mentioned any other parameter
  * FIB memory leak during recursive loop detection
  * Fix passing bad context for callback function
  * NAT: Twice NAT44 (VPP-969)
  * NAT: Add performance testing TRex scripts and config (VPP-832)
  * Provide useful output when installed vpp-dpdk version is incorrect
  * Support kube-proxy data plane
  * SR-MPLS: binary API and automated steering
  * GRE tunnel key includes the FIB table
  * Use crc32 wrapper (VPP-1086)
  * dpdk: unset ETH_TXQ_FLAGS_NOXSUMS only for selected PMDs
  * apps: refactor uri and update build infra
  * Fix icmp/udp/tcp punt/drop paths
  * implement clib_smp_pause() for arm and aarch64 platform
  * fib: fix show fib path-list and path
  * pci: auto-detect right vfio/uio driver
  * vom: acl: Extend constructor for l3 rule
  * vom: acl-list: Add comparison operator - for UT
  * vppinfra: add AVX512 variant of clib_memcpy
  * tap_v2: include host-side parameters in the dump binary API
  * Enable AWS ENA PMD
  * session: fix proxy removal
  * session: generalize handling of network transports
* Mon Jan  8 2018 fstrba@suse.com
- Added patch:
  * vpp-18.01-nojavah.patch
  - Replace javah invocation with javac's -h option
  - Fixes build with jdk10
* Mon Dec 11 2017 marco.varlese@suse.de
- Replace boost-devel BuildRequires with libboost_headers-devel and libboost_thread-devel ([boo#1062583](https://bugzilla.opensuse.org/show_bug.cgi?id=1062583))
* Tue Dec  5 2017 marco.varlese@suse.de
- Updated to vpp-18.01-rc0~365-g8b9a5d19
  * Support for OpenSSL1.1.0
  * GENEVE tunnel
  * Various bug-fixes
* Mon Oct 30 2017 fstrba@suse.com
- Added patch:
  * vpp-17.10-java9.patch
  - Specify java source and target level 8 in order to make the
    java code buildable with jdk9
- Don't require java-1_8_0-openjdk-devel, but java-devel >= 1.8
* Thu Oct 26 2017 marco.varlese@suse.com
- Updated to 17.10-release tarball
- Infrastructure
  * DPDK 17.08
  * IP reassembly
  * Bounded-index extensible hash bucket-level LRU cache
  * Templated timer wheel improvements
- API
  * C/C++ language binding
  * API stats
- Host stack
  * VPP TCP stack scale/congestion improvements
  * VPP Comms Library (VCL)
  * Overall performance, scale and hardening
- Network features
  * IPSec rework - utilize new FIB
  * VPLS and VPWS implementation
  - NAT
  * Renamed SNAT to NAT
  * Performance / Scale
  * Destination NAT44 with load-balancing
  * In2out translation as an output feature on the outside interface
  * Fullback to 3-tuple key for non TCP/UDP/ICMP sessions
  - Security Groups/ACLs
  * "Replace" semantics for adding a new MacIP acl
  * Test suite tests for MacIP ACLs
  - ONE-LISP
  * Map-server fallback support
  * Preemptive re-fetch of active mappings that are about to expire
  * ND termination
  - PPPoE
  * PPPoE Control Plane packet dispatch
  * PPPoE decapsulation
  * PPPoE encapsulation
* Mon Oct  9 2017 marco.varlese@suse.com
- Updated tarball to 17.10-RC1 (vpp-17.10-rc1.tar.xz)
* Fri Sep 29 2017 marco.varlese@suse.com
- Removed 0002-aarch64.patch since change incorporated upstream
- Updated tarball to vpp-17.10-rc0~374-gba3c4e88.tar.xz
* Mon Sep 25 2017 marco.varlese@suse.com
- Updated VPP version
- Removed aarch64 patch since merged upstream
* Fri Aug 25 2017 marco.varlese@suse.com
- Enabled DPDK 17.08 integration
- Removed patch to exclude AESNI since managed upstream
* Wed Aug 23 2017 marco.varlese@suse.com
- Split binaries and libs into sub-packages
- Fixed packages dependencies
* Mon Jul 24 2017 marco.varlese@suse.com
- Upgraded to latest stable release 17.07
* Mon Jun 19 2017 marco.varlese@suse.com
- Updated to latest master vpp-17.07-rc0~396-g7f4d577d
- Fixed provides/conflicts/requires
* Thu Jun  8 2017 marco.varlese@suse.com
- Updated to latest upstream containing the patches for gcc-7
* Wed Jun  7 2017 marco.varlese@suse.com
- Added 0003-startup-conf.patch to fix the default configuration
* Mon Jun  5 2017 marco.varlese@suse.com
- Added 0001-fix-bihash-template.patch
- Added 0002-fix-out2in.patch
- Fix compilation warning as errors with GCC-7
* Thu Jun  1 2017 marco.varlese@suse.com
- Updated to 17.07-rc0
* Wed May 17 2017 marco.varlese@suse.com
- Updated source code to latest upstream
- Added Lua and Java bindings API
- Incorporated DPDK for extra performance and data plane patches
* Wed May  3 2017 bwiedemann@suse.com
- Add reproducible.patch to make build fully reproducible
* Fri Apr 21 2017 marco.varlese@suse.com
- Master of vpp (17.07)
* Wed Feb 15 2017 jengelh@inai.de
- Remove redundant ldconfig calls
* Wed Feb 15 2017 jengelh@inai.de
- Update RPM groups and description
* Wed Jan 25 2017 marco.varlese@suse.com
- Major spec file rework to accomodate changes in plugins build from 17.01 vpp release
- Refactored the libraries included in the different subpackages to avoid unneeded dependencies
* Mon Jan 23 2017 marco.varlese@suse.com
  New features in the VPP 17.01:
- Integrated November 2016 DPDK release
- Complete rework of Forwarding Information Base (FIB)
- Performance Improvements
  * Improvements in DPDK input and output nodes
  * Improvements in L2 path
  * Improvmeents in IPv4 lookup node
- Feature Arcs Improvements
  * Consolidation of the code
  * New feature arcs
  - device-input
  - interface-output
- DPDK Cryptodev Support
  * Software and Hardware Crypto Support
- DPDK HQoS support
- Simple Port Analyzer (SPAN)
- Bidirectional Forwarding Detection
  * Basic implementation
- IPFIX Improvements
- L2 GRE over IPSec tunnels
- Link Layer Discovery Protocol (LLDP)
- Vhost-user Improvements
  * Performance Improvements
  * Multi-queue
  * Reconnect
- LISP Enhancements
  * Source/Dest control plane support
  * L2 over LISP and GRE
  * Map-Register/Map-Notify/RLOC-probing support
  * L2 API improvements, overall code hardening
- Plugins:
  * New: ACL
  * New: Flow per Packet
  * Improved: SNAT
  - Multi-threading
  - Flow export
- Doxygen Enhancements
- Luajit API bindings
- API Refactoring
  * file split
  * message signatures
- Python and Scapy based unit testing infrastructure
  * Infrastructure
  * Various tests
- Packet Generator improvements
- TUN/TAP jumbo frames support
- Other various bug fixes and improvements
